import { describe, it } from 'node:test';
import assert from 'node:assert/strict';
import { formatType, toHex, toUpperSnakeCase } from '../common';

describe('Upper-Snake-Case', () => {
    const tests: [string, string, string][] = [
        ['One Word', 'Hello', 'HELLO'],
        ['Two Words', 'HelloWorld', 'HELLO_WORLD'],
        ['Empty', '', ''],
        ['All Uppercase', 'HELLO', 'HELLO'],
        ['All Lowercase', 'hello', 'HELLO']
    ];
    for (const test of tests) {
        it(test[0], () => {
            assert.strictEqual(toUpperSnakeCase(test[1]), test[2]);
        });
    }
});

describe('Formatting Types For Concatenation', () => {
    const tests: [string, string, string][] = [
        ['Value', 'int', 'int '],
        ['Pointer', 'int *', 'int *'],
        ['Reference', 'int &', 'int &']
    ];
    for (const test of tests) {
        it(test[0], () => {
            assert.strictEqual(formatType(test[1]), test[2]);
        });
    }
});

describe('Hexadecimal', () => {
    const tests: [string, number, string][] = [
        ['Zero', 0, '0x0'],
        ['Small Number', 10, '0xa'],
        ['Large Number', 100, '0x64']
    ];
    for (const test of tests) {
        it(test[0], () => {
            assert.strictEqual(toHex(test[1]), test[2]);
        });
    }
});